@@ -3,6 +3,12 @@
 
 #include <glib.h>
 
+#ifdef G_PLATFORM_WIN32
+#define ORBIT2_MAYBE_CONST
+#else
+#define ORBIT2_MAYBE_CONST const
+#endif
+
 G_BEGIN_DECLS
 
 typedef enum {
@@ -20,7 +26,8 @@ typedef enum {
 	ORBIT_ROT_DYNANY,
 	ORBIT_ROT_OAOBJECT,
 	ORBIT_ROT_ORBGROUP,
-	ORBIT_ROT_POACURRENT
+	ORBIT_ROT_POACURRENT,
+	ORBIT_ROT_CLIENT_POLICY
 } ORBit_RootObject_Type;
 
 typedef struct ORBit_RootObject_struct *ORBit_RootObject;
