@@ -858,7 +858,6 @@ ORBit_POA_obj_to_ref (PortableServer_POA  poa,
 		      const CORBA_char   *intf,
 		      CORBA_Environment  *ev)
 {
-	PortableServer_ObjectId *oid;
 	const char              *type_id = intf;
 
 	g_assert (pobj && !pobj->base.objref);
@@ -870,8 +869,6 @@ ORBit_POA_obj_to_ref (PortableServer_POA  poa,
 
 	g_assert (type_id != NULL);
 
-	oid = pobj->object_id;
-
 	pobj->base.objref = ORBit_objref_new (poa->poa_manager->orb,
 					      &pobj->base,
 					      g_quark_from_string (type_id));
@@ -1385,8 +1382,10 @@ ORBit_POAObject_handle_request (ORBit_POAObject    pobj,
 		ORBit_POAObject_post_invoke (pobj);             
 
  clean_out:
-	POA_UNLOCK (poa);
-	ORBit_RootObject_release (poa);
+	if(poa) {
+		POA_UNLOCK (poa);
+		ORBit_RootObject_release (poa);
+	}
 }
 
 static ORBit_POAObject
